@@ -94,7 +94,7 @@ class gram():
         return self.value
 
     def __add__(self, other):
-        return gram(f"({self.value})+({other.rule()})")
+        return gram(f"{self.value}+{other.rule()}")
 
     def __mul__(self, other):
         return gram(f"{self.value}*{other.rule()}")
@@ -193,30 +193,69 @@ sie = gram('się')
 nie = gram('nie')
 by = gram('by')
 s = gram('s')
-conll = gram('<conll>')
-_root = gram('<root>')
 or1 = gram('or')
 or2 = gram('or2')
-colon = gram('<colon>')
-speaker = gram('<speaker>')
-speaker_end = gram('<speaker-end>')
-squery = gram('<squery>')
-sentence = gram('<sentence>')
-paragraph = gram('<paragraph>')
-subst = gram('<subst>')
-depr = gram('<depr>')
-ppron12 = gram('<ppron12>')
-ppron3 = gram('<ppron3>')
-siebie = gram('<siebie>')
-prep = gram('<prep>')
+do = gram('do')
+w = gram('w')
+na = gram('na')
+location = gram('location')
+time = gram('time')
+link = gram('link')
+
+
+_conll = gram('<conll>')
+_colon = gram('<colon>')
+_speaker = gram('<speaker>')
+_speaker_end = gram('<speaker-end>')
+_squery = gram('<squery>')
+_sentence = gram('<sentence>')
+_paragraph = gram('<paragraph>')
+_subst = gram('<subst>')
+_depr = gram('<depr>')
+_ppron12 = gram('<ppron12>')
+_ppron3 = gram('<ppron3>')
+_siebie = gram('<siebie>')
+_prep = gram('<prep>')
+_numcomp = gram('<numcomp>')
+_intnum = gram('<intnum>')
+_realnum = gram('<realnum>')
+_intnum_interval = gram('<intnum-interval>')
+_realnum_interval = gram('<realnum-interval>')
+_symbol = gram('<symbol>')
+_ordnum = gram('<ordnum>')
+_roman_ordnum = gram('<roman-ordnum>')
+_phone_number = gram('<phone-number>')
+_postal_code = gram('<postal-code>')
+_list_item = gram('<list-item>')
+_fixed = gram('<fixed>')
+_adj = gram('<adj>')
+_apron = gram('<apron>')
+_adjc = gram('<adjc>')
+_adv = gram('<adv>')
+_ger = gram('<ger>')
+_pact = gram('<pact>')
+_ppas = gram('<ppas>')
+_fin = gram('<fin>')
+_bedzie = gram('<bedzie>')
+_praet = gram('<praet>')
+_winien = gram('<winien>')
+_impt = gram('<impt>')
+_imps = gram('<imps>')
+_pred = gram('<pred>')
+_inf = gram('<inf>')
+_pcon = gram('<pcon>')
+_pant = gram('<pant>')
+_comp = gram('<comp>')
+_conj = gram('<conj>')
+_sinterj = gram('<sinterj>')
+_burk = gram('<burk>')
+_interp = gram('<interp>')
+_part = gram('<part>')
+_unk = gram('<unk>')
+_building_number = gram('<building-number>')
+
+_root = gram('<root>')
 _num = gram('<num>')
-numcomp = gram('<numcomp>')
-intnum = gram('<intnum>')
-realnum = gram('<realnum>')
-intnum_interval = gram('<intnum-interval>')
-realnum_interval = gram('<realnum-interval>')
-symbol = gram('<symbol>')
-ordnum = gram('<ordnum>')
 _date = gram('<date>')
 _date_interval = gram('<date-interval>')
 _hour_minute = gram('<hour-minute>')
@@ -232,52 +271,69 @@ _day_month_interval = gram('<day-month-interval>')
 _month_interval = gram('<month-interval>')
 _roman = gram('<roman>')
 _roman_interval = gram('<roman-interval>')
-roman_ordnum = gram('<roman-ordnum>')
 _match_result = gram('<match-result>')
 _url = gram('<url>')
 _email = gram('<email>')
-phone_number = gram('<phone-number>')
-postal_code = gram('<postal-code>')
 _obj_id = gram('<obj-id>')
-list_item = gram('<list-item>')
-fixed = gram('<fixed>')
-adj = gram('<adj>')
-apron = gram('<apron>')
-adjc = gram('<adjc>')
 _adjp = gram('<adjp>')
 _adja = gram('<adja>')
-adv = gram('<adv>')
-ger = gram('<ger>')
-pact = gram('<pact>')
-ppas = gram('<ppas>')
-fin = gram('<fin>')
-bedzie = gram('<bedzie>')
-praet = gram('<praet>')
-winien = gram('<winien>')
-impt = gram('<impt>')
-imps = gram('<imps>')
-pred = gram('<pred>')
 _aglt = gram('<aglt>')
-inf = gram('<inf>')
-pcon = gram('<pcon>')
-pant = gram('<pant>')
 _qub = gram('<qub>')
-comp = gram('<comp>')
 _compar = gram('<compar>')
-conj = gram('<conj>')
 _interj = gram('<interj>')
-sinterj = gram('<sinterj>')
-burk = gram('<burk>')
-interp = gram('<interp>')
-part = gram('<part>')
-unk = gram('<unk>')
-building_number = gram('<building-number>')
-do = gram('do')
-w = gram('w')
-na = gram('na')
-location = gram('location')
-time = gram('time')
-link = gram('link')
+
+
+colon = gram('colon')
+speaker = gram('speaker')
+speaker_end = gram('end')
+squery = gram('squery')
+sentence = gram('sentence')
+paragraph = gram('paragraph')
+subst = gram('subst')
+depr = gram('depr')
+ppron12 = gram('ppron12')
+ppron3 = gram('ppron3')
+siebie = gram('siebie')
+prep = gram('prep')
+numcomp = gram('numcomp')
+intnum = gram('intnum')
+realnum = gram('realnum')
+intnum_interval = gram('interval')
+realnum_interval = gram('interval')
+symbol = gram('symbol')
+ordnum = gram('ordnum')
+roman_ordnum = gram('ordnum')
+phone_number = gram('number')
+postal_code = gram('code')
+list_item = gram('item')
+fixed = gram('fixed')
+adj = gram('adj')
+apron = gram('apron')
+adjc = gram('adjc')
+adv = gram('adv')
+ger = gram('ger')
+pact = gram('pact')
+ppas = gram('ppas')
+fin = gram('fin')
+bedzie = gram('bedzie')
+praet = gram('praet')
+winien = gram('winien')
+impt = gram('impt')
+imps = gram('imps')
+pred = gram('pred')
+inf = gram('inf')
+pcon = gram('pcon')
+pant = gram('pant')
+comp = gram('comp')
+conj = gram('conj')
+sinterj = gram('sinterj')
+burk = gram('burk')
+interp = gram('interp')
+part = gram('part')
+unk = gram('unk')
+building_number = gram('number')
+
+
 lemma = gram('lemma')
 cat = gram('cat')
 pos = gram('pos')
@@ -304,4 +360,4 @@ inst = gram('inst')
 loc = gram('loc')
 postp = gram('postp')
 n = gram('n')
-sg = gram('sg')
+sg = gram('sg')
\ No newline at end of file
